diff Include/code.h @ 38244:a637c78bf119 legacy-trunk

Merge from rjones-funccall branch. Applied patch zombie-frames-2.diff from sf patch 876206 with updates for Python 2.5 and also modified to retain the free_list to avoid the 67% slow-down in pybench recursion test. 5% speed up in function call pybench.
author Richard Jones <richard@commonground.com.au>
date Tue, 23 May 2006 10:37:38 +0000
parents cc48985c3266
children eeda2704130e
line wrap: on
line diff
--- a/Include/code.h	Tue May 23 10:12:21 2006 +0000
+++ b/Include/code.h	Tue May 23 10:37:38 2006 +0000
@@ -24,6 +24,7 @@
     PyObject *co_name;		/* string (name, for reference) */
     int co_firstlineno;		/* first source line number */
     PyObject *co_lnotab;	/* string (encoding addr<->lineno mapping) */
+    void *co_zombieframe;     /* for optimization only (see frameobject.c) */
 } PyCodeObject;
 
 /* Masks for co_flags above */